@@ -25,6 +25,7 @@
 
 #include <gdk/gdkkeysyms.h>
 
+#include <gtk/gtkversion.h>
 #include <gtk/gtkaboutdialog.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkiconfactory.h>
@@ -74,7 +75,6 @@
 #define SHOW_SCREEN_KEY	"/apps/fast-user-switch-applet/show_screen_item"
 #define ACTIVE_ONLY_KEY	"/apps/fast-user-switch-applet/show_active_users_only"
 
-
 /* ******************** *
  *  Private Structures  *
  * ******************** */
@@ -527,7 +527,7 @@ applet_fill_cb (PanelApplet *applet,
   gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu), adata->separator_item);
   adata->items = g_slist_prepend (adata->items, adata->separator_item);
 
-  adata->login_screen_item = gtk_image_menu_item_new_with_label (_("Login Screen"));
+  adata->login_screen_item = gtk_image_menu_item_new_with_label (_("Other"));
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (adata->login_screen_item),
 				 gtk_image_new ());
   gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu),
@@ -636,7 +636,6 @@ applet_style_set_cb (GtkWidget *widget,
   theme = gtk_icon_theme_get_for_screen (screen);
   component = panel_applet_get_popup_component (PANEL_APPLET (widget));
 
-  g_message ("Setting icons");
   set_menuitem_icon (component, "/commands/FusaAboutMe",
 		     theme, "user-info", icon_size);
   set_menuitem_icon (component, "/commands/FusaUsersGroupsAdmin",
@@ -747,6 +746,13 @@ applet_size_allocate_cb (GtkWidget     *widget,
   GtkWidget *top_item;
   PanelAppletOrient orient;
   gint item_border;
+  gint pixel_size;
+#if GTK_CHECK_VERSION (2,7,0)
+  gdouble text_angle = 0.0;
+  GtkPackDirection pack_direction = GTK_PACK_DIRECTION_LTR;
+#else
+  PangoEllipsizeMode ellipsize_mode;
+#endif
 
   adata = data;
   children = gtk_container_get_children (GTK_CONTAINER (adata->menubar));
@@ -763,35 +769,59 @@ applet_size_allocate_cb (GtkWidget     *widget,
     case PANEL_APPLET_ORIENT_UP:
     case PANEL_APPLET_ORIENT_DOWN:
       gtk_widget_set_size_request (top_item, -1, allocation->height);
-#ifdef HAVE_GTK28
-      gtk_menu_bar_set_pack_direction (GTK_MENU_BAR (adata->menubar),
-	      			       GTK_PACK_DIRECTION_RTL);
+      pixel_size = allocation->height - item_border;
+#if GTK_CHECK_VERSION (2,7,0)
+      pack_direction = GTK_PACK_DIRECTION_RTL;
+      text_angle = 0.0;
+#else
+      ellipsize_mode = PANGO_ELLIPSIZE_NONE;
 #endif /* HAVE_GTK28 */
-      if (GTK_IS_IMAGE (adata->imglabel))
-	gtk_image_set_pixel_size (GTK_IMAGE (adata->imglabel),
-				  allocation->height - item_border);
-      else
-	gtk_label_set_ellipsize (GTK_LABEL (adata->imglabel),
-				 PANGO_ELLIPSIZE_NONE);
       break;
     case PANEL_APPLET_ORIENT_LEFT:
+      gtk_widget_set_size_request (top_item, allocation->width, -1);
+      pixel_size = allocation->width - item_border;
+#if GTK_CHECK_VERSION (2,7,0)
+      pack_direction = GTK_PACK_DIRECTION_TTB;
+      text_angle = 270.0;
+#else
+      ellipsize_mode = PANGO_ELLIPSIZE_END;
+#endif /* HAVE_GTK28 */
+      break;
     case PANEL_APPLET_ORIENT_RIGHT:
       gtk_widget_set_size_request (top_item, allocation->width, -1);
-#ifdef HAVE_GTK28
-      gtk_menu_bar_set_pack_direction (GTK_MENU_BAR (adata->menubar),
-				       GTK_PACK_DIRECTION_TTB);
+      pixel_size = allocation->width - item_border;
+#if GTK_CHECK_VERSION (2,7,0)
+      pack_direction = GTK_PACK_DIRECTION_TTB;
+      text_angle = 90.0;
+#else
+      ellipsize_mode = PANGO_ELLIPSIZE_END;
 #endif /* HAVE_GTK28 */
-      if (GTK_IS_IMAGE (adata->imglabel))
-	gtk_image_set_pixel_size (GTK_IMAGE (adata->imglabel),
-				  allocation->width - item_border);
-      else
-	gtk_label_set_ellipsize (GTK_LABEL (adata->imglabel),
-				 PANGO_ELLIPSIZE_END);
       break;
     default:
       g_assert_not_reached ();
       break;
     }
+
+#if GTK_CHECK_VERSION (2,7,0)
+  gtk_menu_bar_set_pack_direction (GTK_MENU_BAR (adata->menubar),
+                                   pack_direction);
+#endif /* HAVE_GTK28 */
+
+  if (GTK_IS_IMAGE (adata->imglabel))
+    {
+      gtk_image_set_pixel_size (GTK_IMAGE (adata->imglabel),
+                                pixel_size);
+    }
+  else
+    {
+#if GTK_CHECK_VERSION (2,7,0)
+      gtk_label_set_angle (GTK_LABEL (adata->imglabel), text_angle);
+#else
+      gtk_label_set_ellipsize (GTK_LABEL (adata->imglabel),
+                               ellipsize_mode);
+#endif
+
+    }
 }
 
 
@@ -2231,14 +2261,18 @@ maybe_lock_screen (FusaAppletData *adata,
       gchar *args[3];
       GError *err;
       GdkScreen *screen;
+      gboolean use_gscreensaver = TRUE;
 
       args[0] = g_find_program_in_path ("gnome-screensaver-command");
       if (!args[0])
-	args[0] = g_find_program_in_path ("xscreensaver-command");
+        {
+          args[0] = g_find_program_in_path ("xscreensaver-command");
+          use_gscreensaver = FALSE;
+        }
       if (!args[0])
 	return;
 
-      if (args[0][0] == 'g')
+      if (use_gscreensaver)
 	args[1] = "--lock";
       else
 	args[1] = "-lock";
@@ -2259,7 +2293,7 @@ maybe_lock_screen (FusaAppletData *adata,
 	  g_error_free (err);
 	}
 
-      if (args[0][0] == 'g')
+      if (use_gscreensaver)
 	args[1] = "--throttle";
       else
 	args[1] = "-throttle";
